@@ -22,6 +22,11 @@ def write_data(file_name, data):
     _put_object(config, config['bucket_name'], data, file_name)
 
 
+def write_model(file_name, data):
+    config = _config()
+    _put_object(config, config['bucket_name'], BytesIO(data), file_name)
+
+
 def _put_object(config, bucket, body, object_name):
     print("path upload",config['prefix']+object_name)
     s3_client = boto3.client('s3', aws_access_key_id=config['cortx_authenticator']['access_key_id'], aws_secret_access_key=config['cortx_authenticator']['secret_access_key'], region_name='us-east-1', endpoint_url= config['endpoint_url']) 
